@@ -14,6 +14,7 @@ import (
 	"github.com/openshift/installer/pkg/asset/cluster/aws"
 	"github.com/openshift/installer/pkg/asset/installconfig"
 	"github.com/openshift/installer/pkg/asset/password"
+	"github.com/openshift/installer/pkg/metrics/timer"
 	"github.com/openshift/installer/pkg/terraform"
 )
 
@@ -36,10 +37,13 @@ func (c *Cluster) Dependencies() []asset.Asset {
 	return []asset.Asset{
 		&installconfig.ClusterID{},
 		&installconfig.InstallConfig{},
-		// PlatformCredsCheck just checks the creds (and asks, if needed)
-		// We do not actually use it in this asset directly, hence
-		// it is put in the dependencies but not fetched in Generate
+		// PlatformCredsCheck, PlatformPermsCheck and PlatformProvisionCheck
+		// perform validations & check perms required to provision infrastructure.
+		// We do not actually use them in this asset directly, hence
+		// they are put in the dependencies but not fetched in Generate.
 		&installconfig.PlatformCredsCheck{},
+		&installconfig.PlatformPermsCheck{},
+		&installconfig.PlatformProvisionCheck{},
 		&TerraformVariables{},
 		&password.KubeadminPassword{},
 	}
@@ -78,6 +82,8 @@ func (c *Cluster) Generate(parents asset.Parents) (err error) {
 		}
 	}
 
+	timer.StartTimer("Infrastructure")
+
 	stateFile, err := terraform.Apply(tmpDir, installConfig.Config.Platform.Name(), extraArgs...)
 	if err != nil {
 		err = errors.Wrap(err, "failed to create cluster")
@@ -101,6 +107,7 @@ func (c *Cluster) Generate(parents asset.Parents) (err error) {
 		logrus.Errorf("Failed to read tfstate: %v", err2)
 	}
 
+	timer.StopTimer("Infrastructure")
 	return err
 }
 
